from flask import Flask, request
from flask_cors import CORS
import utils as utils

config = utils.get_config_dict()
git_cmd = utils.git_cmd(config)

## kommt später vom server
xsd_file_name = 'DCC_v1.8.1.xsd'

app = Flask(__name__)
CORS(app)

@app.route('/version', methods=['get'])
def version():
    app.logger.debug('hit version')
    ret = utils.return_version(version=git_cmd.describe())
    
    return utils.xml_response(ret)

@app.route('/update', methods=['post'])
def update():
    app.logger.debug('hit update')
    #req = request.get_json()
    git_cmd.pull()
    app.logger.info("pulled {log}".format(log=git_cmd.log("-n 1")))
    ret = utils.return_ok()

    return utils.xml_response(ret)

@app.route('/update_xsd', methods=['post'])
def update_xsd():
    app.logger.debug('hit update xsd')
    xsd_str = utils.get_xsd(config, xsd_file_name, from_server=True)
    xsd_xml = utils.parse(xsd_str)
    if xsd_xml:
        ret = utils.save_xsd(config, xsd_str, xsd_file_name)
    else:
        ret = utils.return_error(error='error on atempt to parse xsd file from server')

    return  utils.xml_response(ret)


@app.route('/validate', methods=['post'])
def validate():
    app.logger.debug('hit validate')
    xml_str = request.data
    xml_tree = utils.parse(xml_str)
    if xml_tree:
        xsd_str = utils.get_xsd(config, xsd_file_name, from_server=False)
        ret = utils.validate(xml_str=xml_str, xsd_str=xsd_str)
    else:
        ret = utils.return_error(error='unvalid xml data')

    return  utils.xml_response(ret)

if __name__ == '__main__':
    app.run(host=config['server']['host'], port=config['server']['port'])